@@ -422,6 +422,9 @@ class Doc(BaseModel):
             if not extra_attr_dict:
                 continue
             (extra_type, module_name, class_name) = field_tuple
+            # TODO
+            module_name = module_name.replace("docint.extracts", "orgpedia.extracts")            
+            
             if extra_type == "obj":
                 cls = getattr(import_module(module_name), class_name)
                 extra_attr_obj = parse_obj_as(cls, extra_attr_dict)
@@ -451,6 +454,9 @@ class Doc(BaseModel):
                 if not extra_attr_dict:
                     continue
                 (extra_type, module_name, class_name) = field_tuple
+                
+                # TODO
+                module_name = module_name.replace("docint.extracts", "orgpedia.extracts")
                 if extra_type == "obj":
                     cls = getattr(import_module(module_name), class_name)
                     extra_attr_obj = parse_obj_as(cls, extra_attr_dict)
